function get_color,color,INDEX=index,REGEX=regex,RANDOM=random,BRIGHT=bright, $
         DARK=dark,CT=ct
;+
; NAME:
;	GET_COLOR
;
; PURPOSE:
;       To easily return a color or list of colors.
;
;       The default behavior is to return the first color named
;       'color' in the internal color list.  The index of the color
;       entry may also be entered.  The color values and names were
;       obtained from the UNIX command "showrgb".
;
;       A long integer suitable for 24-bit color displays is returned
;       unless /CT is set.  In this case the index of the closest
;       color in the currently loaded color table is returned.  Be
;       sure your color table is loaed first, e.g. with loadct or
;       xloadct, and you set idl for color postscript output with
;       "device,/color".
;
; EXPLANATION:
;       Makes life easier.
;
; CALLING SEQUENCE:
;       get_color,color,[/INDEX],[/REGEX],[/RANDOM],[BRIGHT=],[DARK=],
;                 [/CT]
;
; INPUTS:
;       color = the color you want returned or the number of random
;               colors you want returned (if /RANDOM is set)
;
; OPTIONAL INPUTS:
;      /INDEX = color is the index of the color in the triplets array
;      /REGEX = color is a regular expression search pattern (see the IDL
;               routine stregex)
;      /RANDOM = return color number of random colors
;      bright = sqrt(r*r+g*g+b*b) must be >= bright when randomly
;               selecting colors
;      dark = sqrt(r*r+g*g+b*b) must be <= dark when randomly
;             selecting colors
;      /CT = return the index of the closest color in the currently
;            loaded color table
;
; RETURN VALUE:
;      A long integer or array of long integers suitable for the
;      normal IDL color keyword, or a color table index value if /CT
;      specified.
;
; HISTORY:
;       Written by Michael S. Kelley, UMN, Feb 2004
;       Default behavior changed to name rather than index, MSK, May 2004
;       Added /CT keyword, MSK, Mar 2005
;-
common get_color,seed

if N_params() LT 1 then begin
  print,'Usage: get_color,color,[/INDEX],[/REGEX],[/RANDOM],[BRIGHT=],[DARK=],[/CT]'
  return,1
endif

triplets = [[199, 21, 133],$
  [176, 196, 222],$
  [102, 139, 139],$
  [159, 121, 238],$
  [141, 182, 205],$
  [0, 238, 118],$
  [255, 160, 122],$
  [154, 205, 50],$
  [178, 58, 238],$
  [69, 139, 116],$
  [71, 60, 139],$
  [131, 111, 255],$
  [192, 255, 62],$
  [139, 105, 20],$
  [205, 155, 29],$
  [142, 229, 238],$
  [255, 211, 155],$
  [112, 128, 144],$
  [255, 228, 225],$
  [50, 205, 50],$
  [224, 255, 255],$
  [218, 165, 32],$
  [220, 220, 220],$
  [135, 206, 255],$
  [240, 255, 240],$
  [238, 238, 0],$
  [205, 79, 57],$
  [135, 206, 235],$
  [85, 26, 139],$
  [205, 133, 0],$
  [205, 183, 158],$
  [238, 213, 183],$
  [87, 87, 87],$
  [252, 252, 252],$
  [161, 161, 161],$
  [112, 112, 112],$
  [94, 94, 94],$
  [84, 84, 84],$
  [66, 66, 66],$
  [240, 255, 255],$
  [139, 137, 137],$
  [205, 133, 63],$
  [219, 112, 147],$
  [139, 129, 76],$
  [60, 179, 113],$
  [255, 240, 245],$
  [209, 95, 238],$
  [176, 226, 255],$
  [72, 61, 139],$
  [25, 25, 112],$
  [255, 160, 122],$
  [255, 250, 205],$
  [173, 255, 47],$
  [255, 160, 122],$
  [240, 128, 128],$
  [24, 116, 205],$
  [139, 69, 0],$
  [106, 90, 205],$
  [39, 64, 139],$
  [255, 69, 0],$
  [50, 205, 50],$
  [224, 255, 255],$
  [148, 0, 211],$
  [233, 150, 122],$
  [255, 140, 0],$
  [95, 158, 160],$
  [255, 20, 147],$
  [238, 0, 238],$
  [139, 71, 38],$
  [238, 230, 133],$
  [191, 191, 191],$
  [189, 189, 189],$
  [186, 186, 186],$
  [176, 176, 176],$
  [173, 173, 173],$
  [89, 89, 89],$
  [33, 33, 33],$
  [229, 229, 229],$
  [207, 207, 207],$
  [140, 140, 140],$
  [130, 130, 130],$
  [79, 79, 79],$
  [238, 233, 233],$
  [205, 145, 158],$
  [18, 18, 18],$
  [3, 3, 3],$
  [139, 0, 0],$
  [205, 0, 0],$
  [210, 180, 140],$
  [255, 0, 0],$
  [199, 21, 133],$
  [119, 136, 153],$
  [135, 206, 250],$
  [139, 87, 66],$
  [34, 139, 34],$
  [16, 78, 139],$
  [153, 50, 204],$
  [188, 143, 143],$
  [205, 175, 149],$
  [124, 205, 124],$
  [238, 64, 0],$
  [122, 139, 139],$
  [139, 58, 58],$
  [205, 85, 85],$
  [0, 0, 128],$
  [105, 105, 105],$
  [255, 20, 147],$
  [139, 76, 57],$
  [205, 112, 84],$
  [196, 196, 196],$
  [145, 145, 145],$
  [28, 28, 28],$
  [205, 150, 205],$
  [23, 23, 23],$
  [20, 20, 20],$
  [0, 0, 139],$
  [245, 245, 220],$
  [250, 250, 210],$
  [139, 131, 134],$
  [0, 206, 209],$
  [0, 206, 209],$
  [47, 79, 79],$
  [205, 129, 98],$
  [139, 105, 105],$
  [255, 228, 225],$
  [78, 238, 148],$
  [205, 92, 92],$
  [255, 20, 147],$
  [0, 0, 139],$
  [230, 230, 250],$
  [253, 245, 230],$
  [199, 199, 199],$
  [138, 138, 138],$
  [115, 115, 115],$
  [54, 54, 54],$
  [247, 247, 247],$
  [245, 245, 245],$
  [242, 242, 242],$
  [224, 224, 224],$
  [222, 222, 222],$
  [219, 219, 219],$
  [179, 179, 179],$
  [97, 97, 97],$
  [31, 31, 31],$
  [250, 240, 230],$
  [72, 209, 204],$
  [72, 61, 139],$
  [139, 137, 112],$
  [193, 255, 193],$
  [205, 192, 176],$
  [186, 85, 211],$
  [0, 255, 127],$
  [0, 134, 139],$
  [79, 148, 205],$
  [238, 213, 210],$
  [209, 238, 238],$
  [205, 92, 92],$
  [238, 44, 44],$
  [65, 105, 225],$
  [95, 158, 160],$
  [108, 166, 205],$
  [205, 205, 0],$
  [255, 140, 105],$
  [139, 90, 0],$
  [255, 105, 180],$
  [229, 229, 229],$
  [143, 143, 143],$
  [99, 99, 99],$
  [46, 46, 46],$
  [36, 36, 36],$
  [139, 102, 139],$
  [15, 15, 15],$
  [15, 15, 15],$
  [205, 173, 0],$
  [255, 215, 0],$
  [0, 0, 238],$
  [238, 154, 73],$
  [0, 255, 255],$
  [0, 250, 154],$
  [188, 238, 104],$
  [238, 232, 170],$
  [176, 196, 222],$
  [244, 164, 96],$
  [255, 239, 213],$
  [102, 205, 0],$
  [139, 34, 82],$
  [67, 110, 238],$
  [72, 118, 255],$
  [255, 239, 213],$
  [205, 183, 181],$
  [224, 255, 255],$
  [127, 255, 212],$
  [74, 112, 139],$
  [139, 58, 98],$
  [205, 96, 144],$
  [238, 106, 167],$
  [169, 169, 169],$
  [105, 105, 105],$
  [255, 99, 71],$
  [168, 168, 168],$
  [166, 166, 166],$
  [163, 163, 163],$
  [84, 84, 84],$
  [69, 69, 69],$
  [194, 194, 194],$
  [176, 176, 176],$
  [173, 173, 173],$
  [0, 0, 0],$
  [240, 255, 255],$
  [0, 250, 154],$
  [139, 101, 8],$
  [205, 149, 12],$
  [238, 173, 14],$
  [184, 134, 11],$
  [139, 69, 19],$
  [238, 149, 114],$
  [0, 104, 139],$
  [0, 154, 205],$
  [0, 178, 238],$
  [0, 191, 255],$
  [255, 127, 0],$
  [205, 50, 120],$
  [238, 58, 140],$
  [255, 62, 150],$
  [105, 89, 205],$
  [122, 103, 238],$
  [107, 142, 35],$
  [255, 106, 106],$
  [255, 48, 48],$
  [83, 134, 139],$
  [208, 32, 144],$
  [188, 143, 143],$
  [0, 0, 128],$
  [178, 34, 34],$
  [139, 0, 0],$
  [255, 255, 255],$
  [139, 126, 102],$
  [201, 201, 201],$
  [194, 194, 194],$
  [156, 156, 156],$
  [237, 237, 237],$
  [214, 214, 214],$
  [166, 166, 166],$
  [92, 92, 92],$
  [82, 82, 82],$
  [33, 33, 33],$
  [26, 26, 26],$
  [193, 205, 205],$
  [255, 250, 250],$
  [255, 165, 79],$
  [119, 136, 153],$
  [202, 255, 112],$
  [100, 149, 237],$
  [255, 235, 205],$
  [205, 193, 197],$
  [238, 224, 229],$
  [255, 240, 245],$
  [85, 107, 47],$
  [255, 240, 245],$
  [118, 238, 198],$
  [208, 32, 144],$
  [179, 238, 58],$
  [139, 125, 123],$
  [255, 228, 225],$
  [180, 205, 205],$
  [240, 128, 128],$
  [127, 255, 0],$
  [255, 218, 185],$
  [152, 251, 152],$
  [245, 255, 250],$
  [126, 192, 238],$
  [255, 228, 181],$
  [255, 99, 71],$
  [205, 105, 201],$
  [205, 41, 144],$
  [250, 128, 114],$
  [207, 207, 207],$
  [158, 158, 158],$
  [99, 99, 99],$
  [97, 97, 97],$
  [94, 94, 94],$
  [235, 235, 235],$
  [212, 212, 212],$
  [168, 168, 168],$
  [138, 138, 138],$
  [127, 127, 127],$
  [77, 77, 77],$
  [48, 48, 48],$
  [38, 38, 38],$
  [131, 139, 139],$
  [8, 8, 8],$
  [205, 133, 63],$
  [255, 192, 203],$
  [190, 190, 190],$
  [0, 0, 255],$
  [188, 210, 238],$
  [202, 225, 255],$
  [32, 178, 170],$
  [119, 136, 153],$
  [238, 233, 191],$
  [0, 255, 127],$
  [173, 255, 47],$
  [118, 238, 0],$
  [112, 128, 144],$
  [58, 95, 205],$
  [176, 224, 230],$
  [238, 203, 173],$
  [144, 238, 144],$
  [245, 255, 250],$
  [106, 90, 205],$
  [238, 229, 222],$
  [238, 18, 137],$
  [189, 183, 107],$
  [139, 28, 98],$
  [160, 82, 45],$
  [181, 181, 181],$
  [171, 171, 171],$
  [46, 46, 46],$
  [150, 150, 150],$
  [110, 110, 110],$
  [64, 64, 64],$
  [255, 228, 196],$
  [255, 0, 0],$
  [123, 104, 238],$
  [255, 236, 139],$
  [238, 221, 130],$
  [150, 205, 205],$
  [96, 123, 139],$
  [0, 255, 127],$
  [255, 255, 224],$
  [245, 245, 245],$
  [0, 0, 205],$
  [248, 248, 255],$
  [54, 100, 139],$
  [205, 155, 155],$
  [255, 218, 185],$
  [154, 255, 154],$
  [138, 43, 226],$
  [139, 134, 130],$
  [169, 169, 169],$
  [205, 104, 57],$
  [102, 102, 102],$
  [232, 232, 232],$
  [209, 209, 209],$
  [13, 13, 13],$
  [0, 238, 238],$
  [0, 255, 255],$
  [0, 0, 255],$
  [255, 250, 250],$
  [238, 220, 130],$
  [132, 112, 255],$
  [180, 82, 205],$
  [105, 139, 105],$
  [0, 205, 102],$
  [34, 139, 34],$
  [108, 123, 139],$
  [159, 182, 205],$
  [185, 211, 238],$
  [65, 105, 225],$
  [139, 119, 101],$
  [84, 139, 84],$
  [152, 251, 152],$
  [205, 55, 0],$
  [255, 193, 37],$
  [248, 248, 255],$
  [139, 26, 26],$
  [205, 38, 38],$
  [122, 197, 205],$
  [112, 128, 144],$
  [205, 197, 191],$
  [193, 205, 193],$
  [139, 136, 120],$
  [238, 232, 205],$
  [155, 48, 255],$
  [105, 105, 105],$
  [139, 0, 0],$
  [255, 246, 143],$
  [205, 205, 193],$
  [179, 179, 179],$
  [153, 153, 153],$
  [82, 82, 82],$
  [56, 56, 56],$
  [31, 31, 31],$
  [250, 250, 250],$
  [227, 227, 227],$
  [181, 181, 181],$
  [163, 163, 163],$
  [153, 153, 153],$
  [125, 125, 125],$
  [224, 238, 238],$
  [8, 8, 8],$
  [187, 255, 255],$
  [171, 130, 255],$
  [147, 112, 219],$
  [255, 250, 205],$
  [0, 191, 255],$
  [205, 179, 139],$
  [191, 62, 255],$
  [255, 140, 0],$
  [238, 180, 34],$
  [189, 183, 107],$
  [238, 118, 33],$
  [238, 197, 145],$
  [240, 255, 240],$
  [0, 100, 0],$
  [205, 181, 205],$
  [238, 210, 238],$
  [255, 225, 255],$
  [0, 0, 139],$
  [216, 191, 216],$
  [238, 48, 167],$
  [255, 52, 179],$
  [135, 135, 135],$
  [112, 112, 112],$
  [64, 64, 64],$
  [189, 189, 189],$
  [115, 115, 115],$
  [105, 105, 105],$
  [89, 89, 89],$
  [69, 69, 69],$
  [59, 59, 59],$
  [41, 41, 41],$
  [139, 35, 35],$
  [245, 222, 179],$
  [255, 127, 80],$
  [139, 90, 43],$
  [250, 250, 210],$
  [132, 112, 255],$
  [85, 107, 47],$
  [47, 79, 79],$
  [205, 104, 137],$
  [93, 71, 139],$
  [137, 104, 205],$
  [139, 69, 19],$
  [176, 224, 230],$
  [104, 34, 139],$
  [154, 50, 205],$
  [255, 218, 185],$
  [105, 139, 34],$
  [104, 131, 139],$
  [255, 182, 193],$
  [211, 211, 211],$
  [224, 238, 224],$
  [255, 248, 220],$
  [253, 245, 230],$
  [255, 130, 71],$
  [139, 125, 107],$
  [218, 112, 214],$
  [205, 198, 115],$
  [214, 214, 214],$
  [212, 212, 212],$
  [209, 209, 209],$
  [184, 184, 184],$
  [133, 133, 133],$
  [110, 110, 110],$
  [66, 66, 66],$
  [36, 36, 36],$
  [26, 26, 26],$
  [191, 191, 191],$
  [135, 135, 135],$
  [54, 54, 54],$
  [51, 51, 51],$
  [205, 51, 51],$
  [20, 20, 20],$
  [238, 0, 0],$
  [0, 0, 128],$
  [190, 190, 190],$
  [255, 215, 0],$
  [102, 205, 170],$
  [238, 221, 130],$
  [82, 139, 139],$
  [155, 205, 155],$
  [180, 238, 180],$
  [139, 131, 120],$
  [250, 235, 215],$
  [0, 139, 69],$
  [139, 139, 122],$
  [255, 250, 240],$
  [127, 255, 212],$
  [0, 197, 205],$
  [92, 172, 238],$
  [238, 180, 180],$
  [255, 182, 193],$
  [211, 211, 211],$
  [238, 99, 99],$
  [30, 144, 255],$
  [0, 100, 0],$
  [84, 255, 159],$
  [139, 10, 80],$
  [240, 248, 255],$
  [255, 0, 255],$
  [255, 105, 180],$
  [238, 121, 66],$
  [255, 131, 250],$
  [255, 255, 255],$
  [247, 247, 247],$
  [240, 240, 240],$
  [222, 222, 222],$
  [219, 219, 219],$
  [130, 130, 130],$
  [107, 107, 107],$
  [48, 48, 48],$
  [240, 240, 240],$
  [217, 217, 217],$
  [156, 156, 156],$
  [238, 59, 59],$
  [240, 230, 140],$
  [3, 3, 3],$
  [139, 117, 0],$
  [123, 104, 238],$
  [60, 179, 113],$
  [47, 79, 79],$
  [175, 238, 238],$
  [175, 238, 238],$
  [122, 55, 139],$
  [238, 223, 204],$
  [238, 238, 209],$
  [144, 238, 144],$
  [148, 0, 211],$
  [233, 150, 122],$
  [127, 255, 0],$
  [0, 245, 255],$
  [244, 164, 96],$
  [255, 69, 0],$
  [255, 174, 185],$
  [178, 223, 238],$
  [191, 239, 255],$
  [211, 211, 211],$
  [46, 139, 87],$
  [67, 205, 128],$
  [173, 216, 230],$
  [205, 16, 118],$
  [169, 169, 169],$
  [0, 139, 139],$
  [222, 184, 135],$
  [255, 245, 238],$
  [255, 110, 180],$
  [105, 105, 105],$
  [0, 139, 139],$
  [139, 139, 0],$
  [255, 255, 0],$
  [160, 32, 240],$
  [255, 165, 0],$
  [139, 139, 131],$
  [252, 252, 252],$
  [227, 227, 227],$
  [161, 161, 161],$
  [148, 148, 148],$
  [125, 125, 125],$
  [79, 79, 79],$
  [61, 61, 61],$
  [51, 51, 51],$
  [0, 139, 0],$
  [0, 255, 0],$
  [186, 186, 186],$
  [171, 171, 171],$
  [205, 91, 69],$
  [238, 106, 80],$
  [238, 174, 238],$
  [139, 99, 108],$
  [255, 255, 240],$
  [10, 10, 10],$
  [5, 5, 5],$
  [238, 201, 0],$
  [102, 205, 170],$
  [119, 136, 153],$
  [205, 190, 112],$
  [162, 205, 90],$
  [255, 185, 15],$
  [184, 134, 11],$
  [186, 85, 211],$
  [255, 250, 205],$
  [139, 121, 94],$
  [0, 191, 255],$
  [255, 255, 224],$
  [255, 250, 240],$
  [30, 144, 255],$
  [0, 0, 205],$
  [144, 238, 144],$
  [139, 69, 19],$
  [205, 102, 29],$
  [139, 115, 85],$
  [64, 224, 208],$
  [70, 130, 180],$
  [46, 139, 87],$
  [124, 252, 0],$
  [131, 139, 131],$
  [169, 169, 169],$
  [46, 139, 87],$
  [139, 71, 137],$
  [255, 231, 186],$
  [238, 130, 238],$
  [255, 255, 240],$
  [224, 224, 224],$
  [217, 217, 217],$
  [145, 145, 145],$
  [143, 143, 143],$
  [140, 140, 140],$
  [122, 122, 122],$
  [120, 120, 120],$
  [117, 117, 117],$
  [77, 77, 77],$
  [43, 43, 43],$
  [120, 120, 120],$
  [74, 74, 74],$
  [238, 169, 184],$
  [13, 13, 13],$
  [10, 10, 10],$
  [0, 255, 0],$
  [0, 0, 0],$
  [165, 42, 42],$
  [110, 123, 139],$
  [110, 139, 61],$
  [139, 71, 93],$
  [135, 206, 250],$
  [121, 205, 205],$
  [141, 238, 238],$
  [151, 255, 255],$
  [255, 235, 205],$
  [238, 232, 170],$
  [25, 25, 112],$
  [32, 178, 170],$
  [205, 201, 165],$
  [47, 79, 79],$
  [154, 205, 50],$
  [143, 188, 143],$
  [250, 235, 215],$
  [238, 118, 0],$
  [69, 139, 0],$
  [70, 130, 180],$
  [255, 193, 193],$
  [154, 205, 50],$
  [238, 162, 173],$
  [255, 69, 0],$
  [139, 123, 139],$
  [135, 206, 235],$
  [255, 248, 220],$
  [238, 130, 98],$
  [238, 122, 233],$
  [238, 238, 224],$
  [237, 237, 237],$
  [235, 235, 235],$
  [232, 232, 232],$
  [92, 92, 92],$
  [74, 74, 74],$
  [71, 71, 71],$
  [41, 41, 41],$
  [201, 201, 201],$
  [199, 199, 199],$
  [196, 196, 196],$
  [122, 122, 122],$
  [43, 43, 43],$
  [139, 62, 47],$
  [255, 114, 86],$
  [255, 187, 255],$
  [255, 181, 197],$
  [23, 23, 23],$
  [5, 5, 5],$
  [18, 18, 18],$
  [0, 139, 139],$
  [0, 0, 205],$
  [221, 160, 221],$
  [100, 149, 237],$
  [164, 211, 238],$
  [255, 239, 219],$
  [238, 207, 161],$
  [255, 222, 173],$
  [205, 205, 180],$
  [139, 0, 139],$
  [255, 222, 173],$
  [205, 102, 0],$
  [245, 245, 245],$
  [0, 229, 238],$
  [99, 184, 255],$
  [139, 95, 101],$
  [154, 192, 205],$
  [124, 252, 0],$
  [255, 127, 36],$
  [240, 248, 255],$
  [107, 142, 35],$
  [211, 211, 211],$
  [210, 105, 30],$
  [139, 0, 139],$
  [205, 0, 205],$
  [255, 255, 0],$
  [125, 38, 205],$
  [145, 44, 238],$
  [238, 154, 0],$
  [255, 165, 0],$
  [255, 0, 255],$
  [255, 228, 196],$
  [238, 216, 174],$
  [176, 48, 96],$
  [139, 134, 78],$
  [245, 245, 245],$
  [242, 242, 242],$
  [204, 204, 204],$
  [127, 127, 127],$
  [105, 105, 105],$
  [38, 38, 38],$
  [28, 28, 28],$
  [204, 204, 204],$
  [148, 148, 148],$
  [102, 102, 102],$
  [87, 87, 87],$
  [56, 56, 56],$
  [255, 64, 64],$
  [205, 201, 201],$
  [72, 209, 204],$
  [162, 181, 205],$
  [238, 121, 159],$
  [255, 130, 171],$
  [174, 238, 238],$
  [143, 188, 143],$
  [219, 112, 147],$
  [224, 102, 255],$
  [255, 222, 173],$
  [147, 112, 219],$
  [255, 255, 224],$
  [28, 134, 238],$
  [30, 144, 255],$
  [139, 0, 139],$
  [138, 43, 226],$
  [102, 205, 170],$
  [198, 226, 255],$
  [112, 128, 144],$
  [139, 37, 0],$
  [205, 140, 149],$
  [173, 216, 230],$
  [153, 50, 204],$
  [152, 245, 255],$
  [205, 170, 125],$
  [255, 245, 238],$
  [205, 200, 177],$
  [139, 54, 38],$
  [238, 92, 66],$
  [205, 186, 150],$
  [250, 250, 250],$
  [150, 150, 150],$
  [59, 59, 59],$
  [0, 205, 0],$
  [0, 238, 0],$
  [184, 184, 184],$
  [158, 158, 158],$
  [133, 133, 133],$
  [117, 117, 117],$
  [107, 107, 107],$
  [71, 71, 71],$
  [61, 61, 61],$
  [255, 255, 255],$
  [0, 205, 205],$
  [0, 0, 0]]

colornames = ['medium',$
  'light',$
  'paleturquoise4',$
  'mediumpurple2',$
  'lightskyblue3',$
  'springgreen2',$
  'light',$
  'yellowgreen',$
  'darkorchid2',$
  'aquamarine4',$
  'slateblue4',$
  'slateblue1',$
  'olivedrab1',$
  'goldenrod4',$
  'goldenrod3',$
  'cadetblue2',$
  'burlywood1',$
  'slategrey',$
  'mistyrose',$
  'limegreen',$
  'lightcyan',$
  'goldenrod',$
  'gainsboro',$
  'skyblue1',$
  'honeydew',$
  'yellow2',$
  'tomato3',$
  'skyblue',$
  'purple4',$
  'orange3',$
  'bisque3',$
  'bisque2',$
  'grey34',$
  'gray99',$
  'gray63',$
  'gray44',$
  'gray37',$
  'gray33',$
  'gray26',$
  'azure1',$
  'snow4',$
  'peru',$
  'pale',$
  'lightgoldenrod4',$
  'mediumseagreen',$
  'lavender',$
  'mediumorchid2',$
  'lightskyblue1',$
  'darkslateblue',$
  'midnightblue',$
  'lightsalmon1',$
  'lemonchiffon',$
  'green',$
  'lightsalmon',$
  'light',$
  'dodgerblue3',$
  'darkorange4',$
  'slate',$
  'royalblue4',$
  'orange',$
  'lime',$
  'light',$
  'darkviolet',$
  'darksalmon',$
  'darkorange',$
  'cadet',$
  'deep',$
  'magenta2',$
  'sienna4',$
  'khaki2',$
  'grey75',$
  'grey74',$
  'grey73',$
  'grey69',$
  'grey68',$
  'grey35',$
  'grey13',$
  'gray90',$
  'gray81',$
  'gray55',$
  'gray51',$
  'gray31',$
  'snow2',$
  'pink3',$
  'grey7',$
  'gray1',$
  'red4',$
  'red3',$
  'tan',$
  'red',$
  'mediumvioletred',$
  'lightslategrey',$
  'lightskyblue',$
  'lightsalmon4',$
  'forestgreen',$
  'dodgerblue4',$
  'dark',$
  'rosy',$
  'peachpuff3',$
  'palegreen3',$
  'orangered2',$
  'lightcyan4',$
  'indianred4',$
  'indianred3',$
  'navyblue',$
  'dim',$
  'deeppink',$
  'salmon4',$
  'salmon3',$
  'grey77',$
  'gray57',$
  'gray11',$
  'plum3',$
  'gray9',$
  'gray8',$
  'blue4',$
  'beige',$
  'light',$
  'lavenderblush4',$
  'dark',$
  'darkturquoise',$
  'darkslategrey',$
  'lightsalmon3',$
  'rosybrown4',$
  'misty',$
  'seagreen2',$
  'indianred',$
  'deeppink1',$
  'dark',$
  'lavender',$
  'oldlace',$
  'grey78',$
  'grey54',$
  'grey45',$
  'grey21',$
  'gray97',$
  'gray96',$
  'gray95',$
  'gray88',$
  'gray87',$
  'gray86',$
  'gray70',$
  'gray38',$
  'gray12',$
  'linen',$
  'medium',$
  'dark',$
  'lemonchiffon4',$
  'darkseagreen1',$
  'antiquewhite3',$
  'mediumorchid',$
  'springgreen',$
  'turquoise4',$
  'steelblue3',$
  'mistyrose2',$
  'lightcyan2',$
  'indian',$
  'firebrick2',$
  'royalblue',$
  'cadetblue',$
  'skyblue3',$
  'yellow3',$
  'salmon1',$
  'orange4',$
  'hotpink',$
  'grey90',$
  'gray56',$
  'gray39',$
  'gray18',$
  'gray14',$
  'plum4',$
  'grey6',$
  'gray6',$
  'gold3',$
  'gold1',$
  'blue2',$
  'tan2',$
  'cyan',$
  'mediumspringgreen',$
  'darkolivegreen2',$
  'pale',$
  'lightsteelblue',$
  'sandy',$
  'papaya',$
  'chartreuse3',$
  'violetred4',$
  'royalblue2',$
  'royalblue1',$
  'papayawhip',$
  'mistyrose3',$
  'lightcyan1',$
  'aquamarine',$
  'skyblue4',$
  'hotpink4',$
  'hotpink3',$
  'hotpink2',$
  'darkgrey',$
  'dimgray',$
  'tomato',$
  'grey66',$
  'grey65',$
  'grey64',$
  'grey33',$
  'grey27',$
  'gray76',$
  'gray69',$
  'gray68',$
  'grey0',$
  'azure',$
  'medium',$
  'darkgoldenrod4',$
  'darkgoldenrod3',$
  'darkgoldenrod2',$
  'darkgoldenrod',$
  'saddle',$
  'lightsalmon2',$
  'deepskyblue4',$
  'deepskyblue3',$
  'deepskyblue2',$
  'deepskyblue',$
  'darkorange1',$
  'violetred3',$
  'violetred2',$
  'violetred1',$
  'slateblue3',$
  'slateblue2',$
  'olive',$
  'indianred1',$
  'firebrick1',$
  'cadetblue4',$
  'violetred',$
  'rosybrown',$
  'navy',$
  'firebrick',$
  'dark',$
  'grey100',$
  'wheat4',$
  'grey79',$
  'grey76',$
  'grey61',$
  'gray93',$
  'gray84',$
  'gray65',$
  'gray36',$
  'gray32',$
  'gray13',$
  'gray10',$
  'azure3',$
  'snow1',$
  'tan1',$
  'light',$
  'darkolivegreen1',$
  'cornflower',$
  'blanched',$
  'lavenderblush3',$
  'lavenderblush2',$
  'lavenderblush1',$
  'darkolivegreen',$
  'lavenderblush',$
  'aquamarine2',$
  'violet',$
  'olivedrab2',$
  'mistyrose4',$
  'mistyrose1',$
  'lightcyan3',$
  'lightcoral',$
  'chartreuse',$
  'peachpuff',$
  'palegreen',$
  'mintcream',$
  'skyblue2',$
  'moccasin',$
  'tomato1',$
  'orchid3',$
  'maroon3',$
  'salmon',$
  'grey81',$
  'grey62',$
  'grey39',$
  'grey38',$
  'grey37',$
  'gray92',$
  'gray83',$
  'gray66',$
  'gray54',$
  'gray50',$
  'gray30',$
  'gray19',$
  'gray15',$
  'azure4',$
  'grey3',$
  'tan3',$
  'pink',$
  'gray',$
  'blue',$
  'lightsteelblue2',$
  'lightsteelblue1',$
  'light',$
  'lightslategray',$
  'lemonchiffon2',$
  'springgreen1',$
  'greenyellow',$
  'chartreuse2',$
  'slate',$
  'royalblue3',$
  'powderblue',$
  'peachpuff2',$
  'palegreen2',$
  'mint',$
  'slateblue',$
  'seashell2',$
  'deeppink2',$
  'darkkhaki',$
  'maroon4',$
  'sienna',$
  'grey71',$
  'grey67',$
  'grey18',$
  'gray59',$
  'gray43',$
  'gray25',$
  'bisque',$
  'red1',$
  'mediumslateblue',$
  'lightgoldenrod1',$
  'light',$
  'paleturquoise3',$
  'lightskyblue4',$
  'spring',$
  'light',$
  'white',$
  'medium',$
  'ghost',$
  'steelblue4',$
  'rosybrown3',$
  'peachpuff1',$
  'palegreen1',$
  'blueviolet',$
  'seashell4',$
  'darkgray',$
  'sienna3',$
  'grey40',$
  'gray91',$
  'gray82',$
  'gray5',$
  'cyan2',$
  'cyan1',$
  'blue1',$
  'snow',$
  'lightgoldenrod2',$
  'lightslateblue',$
  'mediumorchid3',$
  'darkseagreen4',$
  'springgreen3',$
  'forest',$
  'slategray4',$
  'slategray3',$
  'slategray2',$
  'royal',$
  'peachpuff4',$
  'palegreen4',$
  'pale',$
  'orangered3',$
  'goldenrod1',$
  'ghostwhite',$
  'firebrick4',$
  'firebrick3',$
  'cadetblue3',$
  'slategray',$
  'seashell3',$
  'honeydew3',$
  'cornsilk4',$
  'cornsilk2',$
  'purple1',$
  'dimgrey',$
  'darkred',$
  'khaki1',$
  'ivory3',$
  'grey70',$
  'grey60',$
  'grey32',$
  'grey22',$
  'grey12',$
  'gray98',$
  'gray89',$
  'gray71',$
  'gray64',$
  'gray60',$
  'gray49',$
  'azure2',$
  'gray3',$
  'paleturquoise1',$
  'mediumpurple1',$
  'medium',$
  'lemonchiffon1',$
  'deep',$
  'navajowhite3',$
  'darkorchid1',$
  'dark',$
  'goldenrod2',$
  'dark',$
  'chocolate2',$
  'burlywood2',$
  'honeydew1',$
  'darkgreen',$
  'thistle3',$
  'thistle2',$
  'thistle1',$
  'darkblue',$
  'thistle',$
  'maroon2',$
  'maroon1',$
  'grey53',$
  'grey44',$
  'grey25',$
  'gray74',$
  'gray45',$
  'gray41',$
  'gray35',$
  'gray27',$
  'gray23',$
  'gray16',$
  'brown4',$
  'wheat',$
  'coral',$
  'tan4',$
  'lightgoldenrodyellow',$
  'light',$
  'dark',$
  'dark',$
  'palevioletred3',$
  'mediumpurple4',$
  'mediumpurple3',$
  'saddlebrown',$
  'powder',$
  'darkorchid4',$
  'darkorchid3',$
  'peach',$
  'olivedrab4',$
  'lightblue4',$
  'lightpink',$
  'lightgray',$
  'honeydew2',$
  'cornsilk1',$
  'old',$
  'sienna1',$
  'bisque4',$
  'orchid',$
  'khaki3',$
  'grey84',$
  'grey83',$
  'grey82',$
  'grey72',$
  'grey52',$
  'grey43',$
  'grey26',$
  'grey14',$
  'grey10',$
  'gray75',$
  'gray53',$
  'gray21',$
  'gray20',$
  'brown3',$
  'grey8',$
  'red2',$
  'navy',$
  'grey',$
  'gold',$
  'mediumaquamarine',$
  'lightgoldenrod',$
  'darkslategray4',$
  'darkseagreen3',$
  'darkseagreen2',$
  'antiquewhite4',$
  'antique',$
  'springgreen4',$
  'lightyellow4',$
  'floral',$
  'aquamarine1',$
  'turquoise3',$
  'steelblue2',$
  'rosybrown2',$
  'light',$
  'light',$
  'indianred2',$
  'dodgerblue',$
  'dark',$
  'seagreen1',$
  'deeppink4',$
  'aliceblue',$
  'magenta1',$
  'hot',$
  'sienna2',$
  'orchid1',$
  'gray100',$
  'grey97',$
  'grey94',$
  'grey87',$
  'grey86',$
  'grey51',$
  'grey42',$
  'grey19',$
  'gray94',$
  'gray85',$
  'gray61',$
  'brown2',$
  'khaki',$
  'grey1',$
  'gold4',$
  'medium',$
  'medium',$
  'dark',$
  'pale',$
  'paleturquoise',$
  'mediumorchid4',$
  'antiquewhite2',$
  'lightyellow2',$
  'light',$
  'dark',$
  'dark',$
  'chartreuse1',$
  'turquoise1',$
  'sandybrown',$
  'orangered1',$
  'lightpink1',$
  'lightblue2',$
  'lightblue1',$
  'light',$
  'seagreen4',$
  'seagreen3',$
  'lightblue',$
  'deeppink3',$
  'dark',$
  'dark',$
  'burlywood',$
  'seashell',$
  'hotpink1',$
  'dim',$
  'darkcyan',$
  'yellow4',$
  'yellow',$
  'purple',$
  'orange',$
  'ivory4',$
  'grey99',$
  'grey89',$
  'grey63',$
  'grey58',$
  'grey49',$
  'grey31',$
  'grey24',$
  'grey20',$
  'green4',$
  'green1',$
  'gray73',$
  'gray67',$
  'coral3',$
  'coral2',$
  'plum2',$
  'pink4',$
  'ivory',$
  'gray4',$
  'gray2',$
  'gold2',$
  'medium',$
  'light',$
  'lightgoldenrod3',$
  'darkolivegreen3',$
  'darkgoldenrod1',$
  'dark',$
  'medium',$
  'lemon',$
  'navajowhite4',$
  'deepskyblue1',$
  'lightyellow',$
  'floralwhite',$
  'dodger',$
  'mediumblue',$
  'lightgreen',$
  'chocolate4',$
  'chocolate3',$
  'burlywood4',$
  'turquoise',$
  'steelblue',$
  'sea',$
  'lawngreen',$
  'honeydew4',$
  'dark',$
  'seagreen',$
  'orchid4',$
  'wheat1',$
  'violet',$
  'ivory1',$
  'grey88',$
  'grey85',$
  'grey57',$
  'grey56',$
  'grey55',$
  'grey48',$
  'grey47',$
  'grey46',$
  'grey30',$
  'grey17',$
  'gray47',$
  'gray29',$
  'pink2',$
  'grey5',$
  'grey4',$
  'green',$
  'gray0',$
  'brown',$
  'lightsteelblue4',$
  'darkolivegreen4',$
  'palevioletred4',$
  'light',$
  'darkslategray3',$
  'darkslategray2',$
  'darkslategray1',$
  'blanchedalmond',$
  'palegoldenrod',$
  'midnight',$
  'lightseagreen',$
  'lemonchiffon3',$
  'darkslategray',$
  'yellow',$
  'darkseagreen',$
  'antiquewhite',$
  'darkorange2',$
  'chartreuse4',$
  'steel',$
  'rosybrown1',$
  'olivedrab3',$
  'lightpink2',$
  'orangered',$
  'thistle4',$
  'sky',$
  'cornsilk',$
  'salmon2',$
  'orchid2',$
  'ivory2',$
  'grey93',$
  'grey92',$
  'grey91',$
  'grey36',$
  'grey29',$
  'grey28',$
  'grey16',$
  'gray79',$
  'gray78',$
  'gray77',$
  'gray48',$
  'gray17',$
  'coral4',$
  'coral1',$
  'plum1',$
  'pink1',$
  'grey9',$
  'grey2',$
  'gray7',$
  'cyan4',$
  'blue3',$
  'plum',$
  'cornflowerblue',$
  'lightskyblue2',$
  'antiquewhite1',$
  'navajowhite2',$
  'navajowhite1',$
  'lightyellow3',$
  'dark',$
  'navajowhite',$
  'darkorange3',$
  'whitesmoke',$
  'turquoise2',$
  'steelblue1',$
  'lightpink4',$
  'lightblue3',$
  'lawn',$
  'chocolate1',$
  'alice',$
  'olivedrab',$
  'lightgrey',$
  'chocolate',$
  'magenta4',$
  'magenta3',$
  'yellow1',$
  'purple3',$
  'purple2',$
  'orange2',$
  'orange1',$
  'magenta',$
  'bisque1',$
  'wheat2',$
  'maroon',$
  'khaki4',$
  'grey96',$
  'grey95',$
  'grey80',$
  'grey50',$
  'grey41',$
  'grey15',$
  'grey11',$
  'gray80',$
  'gray58',$
  'gray40',$
  'gray34',$
  'gray22',$
  'brown1',$
  'snow3',$
  'mediumturquoise',$
  'lightsteelblue3',$
  'palevioletred2',$
  'palevioletred1',$
  'paleturquoise2',$
  'dark',$
  'palevioletred',$
  'mediumorchid1',$
  'navajo',$
  'mediumpurple',$
  'lightyellow1',$
  'dodgerblue2',$
  'dodgerblue1',$
  'darkmagenta',$
  'blue',$
  'aquamarine3',$
  'slategray1',$
  'slate',$
  'orangered4',$
  'lightpink3',$
  'light',$
  'darkorchid',$
  'cadetblue1',$
  'burlywood3',$
  'seashell1',$
  'cornsilk3',$
  'tomato4',$
  'tomato2',$
  'wheat3',$
  'grey98',$
  'grey59',$
  'grey23',$
  'green3',$
  'green2',$
  'gray72',$
  'gray62',$
  'gray52',$
  'gray46',$
  'gray42',$
  'gray28',$
  'gray24',$
  'white',$
  'cyan3',$
  'black']

n = n_elements(colornames)
i = indgen(n)
triplets = long(triplets)
colors = reform(triplets[0,i] + 256l*(triplets[1,i] + 256l*triplets[2,i]))

if keyword_set(random) then begin
    i = fix(randomu(seed,color) * n)

    if n_elements(bright) eq 1 then begin
        for j=0,color-1 do begin
            while sqrt(triplets[0,i[j]]*triplets[0,i[j]]+$
                       triplets[1,i[j]]*triplets[1,i[j]]+$
                       triplets[2,i[j]]*triplets[2,i[j]]) lt bright $
              do i[j] = long(randomu(seed) * n)
        endfor
    endif

    if n_elements(dark) eq 1 then begin
        for j=0,color-1 do begin
            while sqrt(triplets[0,i[j]]*triplets[0,i[j]]+$
                       triplets[1,i[j]]*triplets[1,i[j]]+$
                       triplets[2,i[j]]*triplets[2,i[j]]) gt dark $
              do i[j] = fix(randomu(seed) * n)
        endfor
    endif
endif else begin
    ; if index was set, grab that specific color
    if keyword_set(index) then begin
        i = color
    endif else begin
        ; search for color in colornames
        if keyword_set(regex) then pattern = color $
        else pattern = "^" + color + "$"

        match = stregex(colornames,pattern,/boolean)
        i = where(match ne 0)

	; if regex was not specified we should only return the first
        ; color found (e.g. there are multiple colors named 'yellow'
        ; in showrbg)
        if not keyword_set(regex) then i = i[0]
    endelse
endelse

; if we searched for a color and failed, return 1
if i[0] eq -1 then return,1

; if ct is set, find the nearest color in the currently loaded color
; table
if keyword_set(ct) then begin
    returnColor = lonarr(n_elements(i))
    tvlct,ctr,ctg,ctb,/get
    ctr = long(ctr)
    ctg = long(ctg)
    ctb = long(ctb)

    for j=0,n_elements(i)-1 do begin
        distance = (ctr - triplets[0,i[j]])^2 + $
                   (ctg - triplets[1,i[j]])^2 + $
                   (ctb - triplets[2,i[j]])^2
        returnColor[j] = where(distance eq min(distance))
    endfor
endif else returnColor = colors[i]

; if random was set and we only grabbed one color, print out the color
; name for the user's convenience
if keyword_set(random) and n_elements(i) eq 1 then begin
    print,"Found color: " + colornames[i[0]]
    return,returnColor[0]
endif

; if only one color was found, return a scalar value
if n_elements(returnColor) eq 1 then return,returnColor[0]

; otherwise, return the whole list
return,returnColor
end
